#
# spec file for package openucx
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           openucx
Summary:        Unifieid Communication X
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Version:        1.6.0
Release:        lp152.1.6
Url:            http://openucx.org/

#Git-Clone:	git://github.com/openucx/ucx
#Git-Web:	https://github.com/openucx/ucx
Source:         https://github.com/openucx/ucx/releases/download/v%version/ucx-%version.tar.gz
Source1:        baselibs.conf
Patch1:         openucx-s390x-support.patch
BuildRequires:  autoconf >= 2.63
BuildRequires:  automake >= 1.10
BuildRequires:  binutils-devel
BuildRequires:  gcc-c++
BuildRequires:  libibverbs-devel
%if 0%{?suse_version} < 1330
%ifnarch s390x
BuildRequires:  libnuma-devel
%endif
%else
BuildRequires:  libnuma-devel
%endif
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  aarch64 %power64 x86_64 s390x

%description
UCX stands for Unified Communication X. UCX provides an optimized communication
layer for Message Passing (MPI), PGAS/OpenSHMEM libraries and RPC/data-centric
applications. UCX utilizes high-speed networks, such as RDMA (InfiniBand, RoCE,
etc), Cray Gemini or Aries, for inter-node communication. If no such network is
available, TCP is used instead. UCX supports efficient transfer of data in
either main memory (RAM) or GPU memory (through CUDA and ROCm libraries).
In addition, UCX provides efficient intra-node communication, by leveraging the
following shared memory mechanisms: posix, sysv, cma, knem, and xpmem.

%package tools
Summary:        OpenUCX utilities
Group:          System/Console

%description tools
Miscallaneous utilities for Unified Communication X.

%package -n libucm0
Summary:        Memory (un)happing hooks for Unified Communication X
Group:          System/Libraries

%description -n libucm0
libucm is a standalone non-unloadable library which installs hooks
for virtual memory changes in the current process. Then, it calls
user-defined callbacks, which may potentially override the default
behavior, or just passively listen and update their own data. libucm
does not use libuct, to avoid making it non-unloadable as well, and
impelements a basic logging service which is safe to use from malloc
hooks.

%package -n libucm-devel
Summary:        Development files for Unified Communication X Memory Hooks
Group:          Development/Libraries/C and C++
Requires:       libucm0 = %version

%description -n libucm-devel
libucm is a standalone non-unloadable library which installs hooks
for virtual memory changes in the current process.

%package -n libucp0
Summary:        Infiniband Unified Communication Protocols
Group:          System/Libraries

%description -n libucp0
High-level API uses UCT framework to construct protocols commonly
found in applications (MPI, OpenSHMEM, PGAS, etc.)

%package -n libucp-devel
Summary:        Development files for Unified Communication Protocols (UC-P)
Group:          Development/Libraries/C and C++
Requires:       libucp0 = %version

%description -n libucp-devel
High-level API uses UCT framework to construct protocols commonly
found in applications (MPI, OpenSHMEM, PGAS, etc.)

%package -n libucs0
Summary:        Infiniband Unicified Communication Services
Group:          System/Libraries

%description -n libucs0
This framework provides basic infrastructure for component based
programming, memory management, and useful system utilities.

%package -n libucs-devel
Summary:        Development files for Unified Communication Services (UC-S)
Group:          Development/Libraries/C and C++
Requires:       libucs0 = %version

%description -n libucs-devel
This framework provides basic infrastructure for component based
programming, memory management, and useful system utilities.

%package -n libuct0
Summary:        Infiniband Unified Communication Transport
Group:          System/Libraries

%description -n libuct0
Low-level API that expose basic network operations supported by
underlying hardware.

%package -n libuct-devel
Summary:        Development files for Unified Communication Transport (UC-T)
Group:          Development/Libraries/C and C++
Requires:       libuct0 = %version

%description -n libuct-devel
Low-level API that expose basic network operations supported by
underlying hardware.

%prep
%setup -qn ucx-%version
%patch1

%build
autoreconf -fi
export UCX_CFLAGS="%optflags -Wno-error"
%ifarch x86_64
export UCX_CFLAGS="$UCX_CFLAGS -mno-avx"
%endif
%ifarch %ix86
export UCX_CFLAGS="$UCX_CFLAGS -mno-sse -mno-sse2"
%endif
%configure --disable-static --without-avx \
%if 0%{?suse_version} < 1330
%ifarch s390x
         --disable-numa \
%endif
%endif
         --docdir="%_docdir/%name" \
		 --disable-debug --disable-assertions \
		 --disable-params-check \
		 --with-rc --with-ud --with-dc \
		 --with-mlx5-dv --with-rdmacm 

# Override BASE_CFLAGS to disable Werror (boo#1121267)
make %{?_smp_mflags} V=1 BASE_CFLAGS="-g -Wall"

%post   -n libucp0 -p /sbin/ldconfig
%postun -n libucp0 -p /sbin/ldconfig
%post   -n libucs0 -p /sbin/ldconfig
%postun -n libucs0 -p /sbin/ldconfig
%post   -n libuct0 -p /sbin/ldconfig
%postun -n libuct0 -p /sbin/ldconfig
%post   -n libucm0 -p /sbin/ldconfig
%postun -n libucm0 -p /sbin/ldconfig

%install
%make_install
rm -fv "%buildroot/%_libdir"/*.la
rm -fv "%buildroot/%_libdir"/ucx/*.la
# Rename example dir for consistency with the package name
mv %buildroot/%_datadir/ucx  %buildroot/%_datadir/openucx

%files tools
%defattr(-,root,root)
%_bindir/ucx_*
%_datadir/%{name}/
%_libdir/pkgconfig/ucx.pc
%doc LICENSE NEWS

%files -n libucm0
%defattr(-,root,root)
%_libdir/libucm.so.*

%files -n libucm-devel
%defattr(-,root,root)
%_includedir/ucm/
%_libdir/libucm.so

%files -n libucp0
%defattr(-,root,root)
%_libdir/libucp.so.*

%files -n libucp-devel
%defattr(-,root,root)
%_includedir/ucp/
%_libdir/libucp.so

%files -n libucs0
%defattr(-,root,root)
%_libdir/libucs.so.*

%files -n libucs-devel
%defattr(-,root,root)
%_includedir/ucs/
%_libdir/libucs.so

%files -n libuct0
%defattr(-,root,root)
%_libdir/libuct.so.*
%dir %_libdir/ucx/
%_libdir/ucx/libuct_*.so.*

%files -n libuct-devel
%defattr(-,root,root)
%_includedir/uct/
%_libdir/libuct.so
%dir %_libdir/ucx/
%_libdir/ucx/libuct_*.so

%changelog
* Fri Oct  4 2019 Jan Engelhardt <jengelh@inai.de>
- Ensure /usr/lib/ucx is owned at all times.
* Wed Sep 18 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Update to v1.6.0
  - Features:
  - Modular architecture for UCT transports
  - ROCm transport re-design: support for managed memory, direct copy, ROCm GDR
  - Random scheduling policy for DC transport
  - Optimized out-of-box settings for multi-rail
  - Added support for OmniPath (using Verbs)
  - Support for PCI atomics with IB transports
  - Reduced UCP address size for homogeneous environments
  - Bugfixes:
  - Multiple stability and performance improvements in TCP transport
  - Multiple stability fixed in Verbs and MLX5 transports
  - Multiple stability fixes in UCM memory hooks
  - Multiple stability fixes in UGNI transport
  - RPM Spec file cleanup
  - Fixing compilation issues with most recent clang and gcc compilers
  - Fixing the wrong name of aliases
  - Fix data race in UCP wireup
  - Fix segfault when libuct.so is reloaded - issue #3558
  - Include Java sources in distribution
  - Handle EADDRNOTAVAIL in rdma_cm connection manager
  - Disable ibcm on RHEL7+ by default
  - Fix data race in UCP proxy endpoint
  - Static checker fixes
  - Fallback to ibv_create_cq() if ibv_create_cq_ex() returns ENOSYS
  - Fix malloc hooks test
  - Fix checking return status in ucp_client_server example
  - Fix gdrcopy libdir config value
  - Fix printing atomic capabilities in ucx_info
  - Fix perftest warmup iterations to be non-zero
  - Fixing default values for configure logic
  - Fix race condition updating fired_events from multiple threads
  - Fix madvise() hook
- Refresh openucx-s390x-support.patch against new version
* Wed May 15 2019 Nicolas Morey-Chaisemartin <nmoreychaisemartin@suse.com>
- Disable Werror to handle boo#1121267
* Mon Feb 25 2019 nmorey <nmoreychaisemartin@suse.com>
- Update openucx-s390x-support.patch to fix support of 1.5.0 on s390x (bsc#1121267)
- Add baselibs.conf for ppc
* Fri Feb 22 2019 Martin Liška <mliska@suse.cz>
- Update to v1.5.0 (bsc#1121267)
  * Features:
  * New emulation mode enabling full UCX functionality (Atomic, Put, Get)
  * over TCP and RDMA-CORE interconnects which don't implement full RDMA semantics
  * Non-blocking API for all one-sided operations. All blocking communication APIs marked
  * as deprecated
  * New client/server connection establishment API, which allows connected handover between workers
  * Support for rdma-core direct-verbs (DEVX) and DC with mlx5 transports
  * GPU - Support for stream API and receive side pipelining
  * Malloc hooks using binary instrumentation instead of symbol override
  * Statistics for UCT tag API
  * GPU-to-Infiniband HCA affinity support based on locality/distance (PCIe)
  * Bugfixes:
  * Fix overflow in RC/DC flush operations
  * Update description in SPEC file and README
  * Fix RoCE source port for dc_mlx5 flow control
  * Improve ucx_info help message
  * Fix segfault in UCP, due to int truncation in count_one_bits()
  * Multiple other bugfixes (full list on github)
  * Tested configurations:
  * InfiniBand: MLNX_OFED 4.4-4.5, distribution inbox drivers, rdma-core
  * CUDA: gdrcopy 1.2, cuda 9.1.85
  * XPMEM: 2.6.2
  * KNEM: 1.1.2
* Tue Nov  6 2018 nmoreychaisemartin@suse.com
- Update to v1.4.0 (bsc#1103494)
  * Features:
  * Improved support for installation with latest ROCm
  * Improved support for latest rdma-core
  * Added support for CUDA IPC for intra-node GPU, CUDA memory
    allocation cache for mem-type detection, latest Mellanox
    devices, Nvidia GPU managed memory, multiple connections
    between the same pair of workers, large worker address for
    client/server connection establishment and INADDR_ANY, and
    for bitwise atomics operations.
  * Bugfixes:
  * Performance fixes for rendezvous protocol
  * Memory hook fixes
  * Clang support fixes
  * Self tl multi-rail fix
  * Thread safety fixes in IB/RDMA transport
  * Compilation fixes with upstream rdma-core
  * Multiple minor bugfixes (full list on github)
  * Segfault fix for a code generated by armclang compiler
  * UCP memory-domain index fix for zero-copy active messages
* Mon Oct 15 2018 nmoreychaisemartin@suse.com
- Update to v1.3.1 (fate#325996)
  - Prevent potential out-of-order sending in shared memory active messages
  - CUDA: Include cudamem.h in source tarball, pass cudaFree memory size
  - Registration cache: fix large range lookup, handle shmat(REMAP)/mmap(FIXED)
  - Limit IB CQE size for specific ARM boards
* Thu Aug  9 2018 nmoreychaisemartin@suse.com
- Update to v1.3.0 (bsc#1104159)
  - Added stream-based communication API to UCP
  - Added support for GPU platforms: Nvidia CUDA and AMD ROCM software stacks
  - Added API for client/server based connection establishment
  - Added support for TCP transport
  - Support for InfiniBand tag-matching offload for DC and accelerated transports
  - Multi-rail support for eager and rendezvous protocols
  - Added support for tag-matching communications with CUDA buffers
  - Added ucp_rkey_ptr() to obtain pointer for shared memory region
  - Avoid progress overhead on unused transports
  - Improved scalability of software tag-matching by using a hash table
  - Added transparent huge-pages allocator
  - Added non-blocking flush and disconnect for UCP
  - Support fixed-address memory allocation via ucp_mem_map()
  - Added ucp_tag_send_nbr() API to avoid send request allocation
  - Support global addressing in all IB transports
  - Add support for external epoll fd and edge-triggered events
  - Added registration cache for knem
  - Initial support for Java bindings
  - Multiple bugfixes (full list on github)
- Drop UCT-UD-fixed-compilation-by-gcc8.patch as it was fixed upstream
- Refresh openucx-s390x-support.patch against latest sources
* Wed Jun 13 2018 nmoreychaisemartin@suse.com
- Remove libnuma-devel on s390x for older releases
* Tue Mar 27 2018 nmoreychaisemartin@suse.com
- Add UCT-UD-fixed-compilation-by-gcc8.patch to fix compilation
  with GCC8 (bsc#1084635)
* Sat Jan 20 2018 jengelh@inai.de
- Use right documentation path.
* Fri Jan 19 2018 nmoreychaisemartin@suse.com
- Update to 1.2.2
  - Support including UCX API headers from C++ code
  - UD transport to handle unicast flood on RoCE fabric
  - Compilation fixes for gcc 7.1.1, clang 3.6, clang 5
  - When UD transport is used with RoCE, packets intended for other peers may
    arrive on different adapters (as a result of unicast flooding).
  - This change adds packet filtering based on destination GIDs. Now the packet
    is silently dropped, if its destination GID does not match the local GID.
  - Added a new device ID for InfiniBand HCA
* Fri Dec  8 2017 dimstar@opensuse.org
- Drop doxygen BuildRequires: The documentation was already not
  built with this enabled. Removing the BR causes no regression in
  the package but eliminates a build cycle
  boost -> curl -> doxygen -> openucx -> boost
* Tue Sep 19 2017 jengelh@inai.de
- Rediff openucx-s390x-support.patch as p1 to be in line with
  potential git-generated patches.
* Tue Sep 19 2017 nmoreychaisemartin@suse.com
- Switch to version 1.2.1 (Fate#324050)
  Previous 1.3+ version was based on a development branch.
  Supported platforms
  - Shared memory: KNEM, CMA, XPMEM, SYSV, Posix
  - VERBs over InfiniBand and RoCE.
    VERBS over other RDMA interconnects (iWarp, OmniPath, etc.) is available
    for community evaluation and has not been tested in context of this release
  - Cray Gemini and Aries
  - Architectures: x86_64, ARMv8 (64bit), Power64
  Features:
  - Added support for InfiniBand DC and UD transports, including accelerated verbs for Mellanox devices
  - Full support for PGAS/SHMEM interfaces, blocking and non-blocking APIs
  - Support for MPI tag matching, both in software and offload mode
  - Zero copy protocols and rendezvous, registration cache
  - Handling transport errors
  - Flow control for DC/RC
  - Dataypes support: contiguous, IOV, generic
  - Multi-threading support
  - Support for ARMv8 64bit architecture
  - A new API for efficient memory polling
  - Support for malloc-hooks and memory registration caching
* Fri Jun 30 2017 nmoreychaisemartin@suse.com
- Disable avx at configure level
* Wed Jun 28 2017 nmoreychaisemartin@suse.com
- Add openucx-s390x-support.patch to fix compilation on s390x
- Compile openucx on s390x
* Thu Jun  8 2017 nmoreychaisemartin@suse.com
- Fix compilation on ppc
* Fri May 26 2017 jengelh@inai.de
- Update to snapshot 1.3+git44
  * No changelog was found
- Add -Wno-error and disable AVX/SSE as it is not guaranteed
  to exist.
* Sat Jun 18 2016 jengelh@inai.de
- Update to snapshot 0~git1727
  * New: libucm. libucm is a standalone non-unloadable library which
  installs hooks for virtual memory changes in the current process.
* Sun Sep 13 2015 jengelh@inai.de
- Update to snapshot 0~git862
  * License clarification on upstream's behalf
* Mon Jul 27 2015 jengelh@inai.de
- Initial package for build.opensuse.org (version 0~git713)
